import React, {useEffect} from 'react'
import { Routes, Route, Navigate, useNavigate, useLocation } from "react-router-dom";

import { Dashboard } from "./Dashboard";
import { Login } from '../Pages/Login'
import { Home } from '../Pages/Home'
import { Puestos } from '../Pages/Puestos'
import { Contras  } from '../Pages/Contras'
import { Expedientes } from '../Pages/Expedientes'
import { Resultados } from '../Pages/Resultados'
import { Configuracion } from '../Pages/Configuracion'
import { Historial } from '../Pages/Historial'
import { Pruebas } from '../Pages/Pruebas'
import { PruebaNueva } from '../Pages/PruebaNueva'
import { PruebaAsignar } from '../Pages/PruebaAsignar'
import { NotFound } from '../Pages/404'
import { Profile } from '../Pages/Profile'

import useAuth from '../Auth/useAuth'

export function RequireAuth({ children }) {
    let auth = useAuth();
    let location = useLocation();

    console.log('requier auth >> ', auth)


    if (!auth.isLogged()) {
        // Redirect them to the /login page, but save the current location they were
        // trying to go to when they were redirected. This allows us to send them
        // along to that page after they login, which is a nicer user experience
        // than dropping them off on the home page.
        return <Navigate to="/login" state={{ from: location }} replace />;
    }

    return children;
}


export default function MyRoutes () {

    let auth = useAuth();
    let navigate = useNavigate()

    useEffect(() => {
        console.log('usse fec check user')
        if(!auth.isLogged()){
            return navigate('login')
        }else{
            return navigate('dashboard/home')
        }
    },[auth,navigate])

    return(
        <Routes>
            <Route path="/login" element={<Login/>} />
            <Route 
                path="dashboard" 
                element={
                    <RequireAuth>
                        <Dashboard/>
                    </RequireAuth>
                }
            >
                <Route path="home" element={<Home/>} />
                <Route path="puestos" element={<Puestos/>} />
                <Route path="perfil" element={<Profile/>} />
                <Route path="contrasenas" element={<Contras/>} />
                <Route path="expedientes" element={<Expedientes/>} />
                <Route path="resultados" element={<Resultados/>} />
                <Route path="configuraciones" element={<Configuracion/>} />
                <Route path="historial" element={<Historial/>} />
                <Route path="pruebas/listar" element={<Pruebas/>} />
                <Route path="pruebas/crear" element={<PruebaNueva/>} />
                <Route path="pruebas/aplicar" element={<PruebaAsignar/>} />
            </Route>
            <Route path="*" element={<NotFound/>}/>

        </Routes>
    )
}

